/*
	*
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project ( https://gitlab.com/desq/ )
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include "DesQGlobals.hpp"
#include <QtGui>

class QDBusInterface;

class LIBDESQ_DLLSPEC DesQSettings : public QObject {
	Q_OBJECT

	public:
		/*
			* @project -> Project like DesQ or Oyster
			* @app -> Settings of a specific app: Like Files, Term, Shell, etc...
		*/
		DesQSettings( QString app );

		struct DesQProxy {
			QVariant value;

			operator int() const {

				return value.toInt();
			}

			operator float() const {

				return value.toReal();
			}

			operator double() const {

				return value.toDouble();
			}

			operator bool() const {

				return value.toBool();
			}

			operator QString() const {

				return value.toString();
			}

			operator QStringList() const {

				return value.value<QStringList>();
			}

			operator QSize() const {

				return value.toSize();
			}

			operator QFont() const {

				return value.value<QFont>();
			}

			operator QRect() const {

				return value.toRect();
			}
		};

		void reload();

		DesQProxy value( const QString &key );
		QVariant rawValue( const QString &key );
		void setValue( const QString &key, QVariant value );

	private:
		QString mAppName;

		QDBusInterface *iface;

		bool useFallback;
		QSettings *fallback;

	private Q_SLOTS:
		void emitSettings( QVariantMap );

	Q_SIGNALS:
		void settingChanged( QString, QString, QVariant );
};
