/*
	*
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project (https://gitlab.com/desq/)
	*

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once

/* For QString, QThread, QTimer, etc.. */
#include <QtCore>

/* Give No(CPUs), SysInfo - 1/5/15 min cpu load avg, ram/swap info, */
#include <sys/sysinfo.h>

class SysInfo {

    public:
        static SysInfo *sysInfoObject();

        QString hostname() const;
        QString platform() const;
        QString distribution() const;
        QString kernelVersion() const;
        QString cpuModel() const;
        int cpuMaxSpeed() const;
        int cpuCores() const;
        QString username() const;
        QString uptime() const;

        /* Get the current CPU Frequencies */
        QList<double> getCpuSpeeds();

        /* Get the current cpu usage */
        QList<double> getCpuUsage();

        /* Average CPU Loads over all CPUs */
        QList<double> getCpuLoads();

        /* Get the current RAM Usage */
        QList<double> getRamUsage();

        /* Get the current Swap Usage */
        QList<double> getSwapUsage();

    private:
        SysInfo();

        void readOtherInfo();

        QString mHostname;
        QString mPlatform;
        QString mDistribution;
        QString mKernelVersion;
        QString mCpuModel;
        int mCpuSpeed;
        int mCpuCores;
        QString mUsername;
        QString mUptime;

        bool init;

        static SysInfo *info;

        QList<long> lastTotals;
        QList<long> lastIdles;
};
