/*
	*
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project ( https://gitlab.com/desq/ )
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*

	*
	* The class DesQDesktopFile was written by marcusbritanicus as a part of CoreApps
	* Almost the same code is being used here with suitable modifications to name
	* and other parts.
	*
*/

#pragma once

class QIcon;

#include <QtCore>
#include <QIcon>

class DesQDesktopFile {

	public:
		enum Type {
			Application = 0x906AF2,							// A regular executable app
			Link,											// Linux equivalent of '.lnk'			! NOT HANDLED
			Directory										// Desktopthat points to a directory	! NOT HANDLED
		};

		DesQDesktopFile( QString filename = QString() );	// Create an instance of a desktop file

		bool startApplication();
		bool startApplicationWithArgs( QStringList );

		QString desktopName()const;							// Filename of the desktop
		QString name() const;								// Name
		QString genericName() const;						// Generic Name
		QString description() const;						// Comment
		QString exec() const;								// 'TryExec' value or the path divined from 'Exec'
		QString command() const;							// Full command as given in 'Exec'
		QString icon() const;								// Application Icon Name or Path
		QString category() const;							// Main category according to XDG

		QStringList mimeTypes() const;						// MimeTypes handled by this app
		QStringList categories() const;						// Categories this app belongs to
		QStringList parsedExec() const;						// Arguments parsed with %U, %F, %u, %f etc removed

		int type() const;									// Application/Link/Directory
		int rank() const;

		bool visible() const;								// Visible in 'Start' Menu
		bool runInTerminal() const;							// If this app should be run in the terminal
		bool multipleArgs() const;							// Does the app take multiple arguments?
		bool isValid() const;								// Is a valid desktop file

		QString desktopFileUrl() const;						// URL of the desktop file

		// Check if this DesQDesktopFile is equivalent to @other
		bool operator==( const DesQDesktopFile& ) const;

	private:
		QString mFileUrl, mDesktopName, mExec, mCommand;
		QString mName, mGenericName, mDescription, mIcon;
		QString mCategory;
		QStringList mMimeTypes, mCategories, mParsedArgs;

		bool mVisible, mRunInTerminal, mValid = false;
		bool mMultiArgs = false, mTakesArgs = false;

		int mType;

		short int mRank = 3;

		QString desktopPathForName( QString );
		void getCategory();
};

typedef QList<DesQDesktopFile> DesQAppsList;

uint qHash( const DesQDesktopFile &app );
Q_DECLARE_METATYPE( DesQDesktopFile );
